smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton

# ``smartcard`.`CardMonitoring`.`CardMonitoringThread`.`__CardMonitoringThreadSingleton``

class documentation

`class __CardMonitoringThreadSingleton(Thread):`

View In Hierarchy

The real card monitoring thread class.

A single instance of this class is created by the public `CardMonitoringThread` class.

Method | `__init__` | Undocumented
Method | `run` | Runs until stopEvent is notified, and notify observers of all card insertion/removal.
Method | `stop` | Undocumented
Instance Variable | `cardrequest` | Undocumented
Instance Variable | `cards` | Undocumented
Instance Variable | `observable` | Undocumented
Instance Variable | `stopEvent` | Undocumented

def __init__(self, observable):

Undocumented

def run(self):

Runs until stopEvent is notified, and notify observers of all card insertion/removal.

def stop(self):

Undocumented

cardrequest =

Undocumented

cards =

Undocumented

observable =

Undocumented

stopEvent =

Undocumented